#
# spec file for package golang-github-prometheus-promu
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           golang-github-prometheus-promu
Version:        0.15.0
Release:        3.1
Summary:        Prometheus Utility Tool
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/prometheus/promu
Source:         promu-%{version}.tar.gz
Source1:        vendor.tar.gz
# PATCH-FIX-UPSTREAM Fix setting reproducible user and host during the build
# https://github.com/prometheus/promu/pull/267
Patch1:         0001-do_not_discover_user_host_for_reproducible_builds.patch
BuildRequires:  golang-packaging
ExcludeArch:    s390
%{go_provides}
%if 0%{?rhel}
# Fix ERROR: No build ID note found in
%undefine _missing_build_ids_terminate_build
BuildRequires:  golang >= 1.18
%else
BuildRequires:  golang(API) >= 1.19
%endif

%description
The Prometheus Utility Tool is used by the Prometheus project to build other components.

%prep
%autosetup -a1 -p1 -n promu-%{version}

%build
%{goprep} github.com/prometheus/promu
export VERSION=%{version}
export CGO_ENABLED=0
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags "-s -w -X main.version=$VERSION" \
   -o promu ;

%install
install -D -m 0755 promu "%{buildroot}/%{_bindir}/promu"

%files
%doc README.md
%license LICENSE
%{_bindir}/promu

%changelog
* Tue Aug  8 2023 Witek Bedyk <witold.bedyk@suse.com>
- Always set user and host build metadata to constant string to
  achieve reproducible builds (compare reproducible-builds.org)
- Add 0001-do_not_discover_user_host_for_reproducible_builds.patch
- Require Go >= 1.19 for building
- Require Go >= 1.18 for building Red Hat packages
* Tue Jul  4 2023 kastl@b1-systems.de
- Update to version 0.15.0:
  * Release v0.15.0
  * Bump golang.org/x/oauth2 from 0.8.0 to 0.9.0
  * Update common Prometheus files
  * Bump go.uber.org/atomic from 1.10.0 to 1.11.0
  * Update build
  * Add linux/riscv64 to default platforms
  * Bump github.com/prometheus/common from 0.39.0 to 0.42.0
  * Bump golang.org/x/oauth2 from 0.5.0 to 0.6.0
  * Bump github.com/prometheus/common from 0.37.0 to 0.39.0
  * Bump golang.org/x/oauth2 from 0.2.0 to 0.5.0
  * Bump golang.org/x/net from 0.2.0 to 0.7.0
  * Use unmarshalstrict
* Wed Mar 22 2023 Johannes Kastl <kastl@b1-systems.de>
- rework spec file to use obscpio
  - run tar and recompresss services at buildtime
* Tue Jan 10 2023 kastl@b1-systems.de
- Update to version 0.14.0:
  * Add the ability to override tags per GOOS
  * Remove ioutil
  * Update common Prometheus files (#232) (#224)
  * Validate environment variable value
  * Set build date from SOURCE_DATE_EPOCH
- drop patch 0001-Set-build-date-from-SOURCE_DATE_EPOCH.patch that is
  included upstream now
* Mon Oct 31 2022 Witek Bedyk <witold.bedyk@suse.com>
- Do not include source code
- Update to Go 1.18
* Tue Sep 27 2022 Dirk Müller <dmueller@suse.com>
- switch to go1.17 as upstream does (see https://github.com/prometheus/promu/blob/v0.13.0/.promu.yml)
- remove go_nostrip as it isn't necessary with 1.17 anymore
* Tue May 10 2022 Jordi Massaguer <jmassaguerpla@suse.com>
- Exclude s390 architecture.
* Tue Apr 26 2022 Witek Bedyk <witold.bedyk@suse.com>
- Set build date from last changelog modification (boo#1047218)
- Add 0001-Set-build-date-from-SOURCE_DATE_EPOCH.patch
* Fri Apr  1 2022 Stefan Bluhm <stefan.bluhm@clacee.eu>
- Adapted for Enterprise Linux build.
* Thu Mar  3 2022 ecsos@opensuse.org
- Update to version 0.13.0:
  * Release 0.13.0 (jsc#SLE-24138, jsc#SLE-24139)
  * Add deprecation note to pkg directory
  * Add windows/arm64
  * Update common Prometheus files
  * Fix typo
  * Release 0.12.0
  * Simplify CGO crossbuilds
  * Update common Prometheus files
  * Release 0.11.1
  * Fix build with "linux" platform
* Mon Mar  8 2021 Witek Bedyk <witold.bedyk@suse.com>
- Build requires Go 1.15
* Fri Feb  7 2020 Witek Bedyk <witold.bedyk@suse.com>
- Update to 0.5.0
  + Features:
  * Add support for aix/ppc64. #151
  * Fallback to git describe output if no VERSION. #130
  * Make extldflags extensible by configuration. #125
  + Enhancements:
  * cmd/release: add --timeout option. #142
  * cmd/release: create release in GitHub if none exists. #148
  * Avoid bind-mounting to allow building with a remote docker engine #95
  + Bug Fixes:
  * cmd/tarball: restore --prefix flag. #133
  * cmd/release: don't leak credentials in case of error. #136
- Use obs-service-go_modules
* Fri Feb  8 2019 Jan Fajerski <jan.fajerski@suse.com>
- Update to 0.2.0
  + Features:
  * Adding changes to support s390x
  * Add option to disable static linking
  * Add support for 32bit MIPS.
  * Added check_licenses Command to Promu
  + Enhancements:
  * Allow to customize nested options via env variables
  * Bump Go version to 1.11
  * Add warning if promu info is unable to determine repo info
  + Bug Fixes:
  * Fix build on SmartOS by not setting gcc's -static flag
  * Fix git repository url parsing
* Thu Jan 25 2018 kkaempf@suse.com
- Update to 0.1.0
* Wed Mar 29 2017 moio@suse.com
- Initial version
